# Stubs for six.moves.urllib.parse
#
# Note: Commented out items means they weren't implemented at the time.
# Uncomment them when the modules have been added to the typeshed.
from urllib.parse import ParseResult as ParseResult
from urllib.parse import SplitResult as SplitResult
from urllib.parse import parse_qs as parse_qs
from urllib.parse import parse_qsl as parse_qsl
from urllib.parse import urldefrag as urldefrag
from urllib.parse import urljoin as urljoin
from urllib.parse import urlparse as urlparse
from urllib.parse import urlsplit as urlsplit
from urllib.parse import urlunparse as urlunparse
from urllib.parse import urlunsplit as urlunsplit
from urllib.parse import quote as quote
from urllib.parse import quote_plus as quote_plus
from urllib.parse import unquote as unquote
from urllib.parse import unquote_plus as unquote_plus
from urllib.parse import urlencode as urlencode
# from urllib.parse import splitquery as splitquery
# from urllib.parse import splittag as splittag
# from urllib.parse import splituser as splituser
from urllib.parse import uses_fragment as uses_fragment
from urllib.parse import uses_netloc as uses_netloc
from urllib.parse import uses_params as uses_params
from urllib.parse import uses_query as uses_query
from urllib.parse import uses_relative as uses_relative
